@@ -1,13 +1,10 @@
-from random import randint
-
-from twitchbot import Message, Command, get_user_info, format_datetime, get_user_creation_date, get_user_followers, \
-    get_channel_chatters, override_event, Event, Mod, run_command
+from twitchbot import Message, Command
 
 pings = 0
 
 
 @Command('ping', cooldown=3)
-async def cmd_debug(msg: Message, *args):
+async def cmd_ping(msg: Message, *args):
     global pings
     pings += 1
     await msg.reply(f'Pong #{pings}')
